@@ -34,9 +34,13 @@ import com.google.inject.Injector;
 import com.google.inject.Key;
 import com.google.inject.Scope;
 import com.google.inject.TypeLiteral;
+import com.google.inject.spi.InjectionRequest;
+import com.google.inject.spi.MembersInjectorLookup;
 import com.google.inject.spi.ModuleAnnotatedMethodScannerBinding;
+import com.google.inject.spi.ProviderLookup;
 import com.google.inject.spi.ProvisionListenerBinding;
 import com.google.inject.spi.ScopeBinding;
+import com.google.inject.spi.StaticInjectionRequest;
 import com.google.inject.spi.TypeConverterBinding;
 import com.google.inject.spi.TypeListenerBinding;
 import java.lang.annotation.Annotation;
@@ -473,6 +477,46 @@ public class WeakKeySetTest extends TestCase {
       throw new UnsupportedOperationException();
     }
 
+    @Override
+    public void putProviderLookup(ProviderLookup<?> lookup) {
+      throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public Set<ProviderLookup<?>> getProviderLookupsThisLevel() {
+      throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public void putStaticInjectionRequest(StaticInjectionRequest staticInjectionRequest) {
+      throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public Set<StaticInjectionRequest> getStaticInjectionRequestsThisLevel() {
+      throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public Set<InjectionRequest<?>> getInjectionRequestsThisLevel() {
+      throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public Set<MembersInjectorLookup<?>> getMembersInjectorLookupsThisLevel() {
+      throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public void putInjectionRequest(InjectionRequest<?> injectionRequest) {
+      throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public void putMembersInjectorLookup(MembersInjectorLookup<?> membersInjectorLookup) {
+      throw new UnsupportedOperationException();
+    }
+
     @Override
     public ScopeBinding getScopeBinding(Class<? extends Annotation> scopingAnnotation) {
       return null;
@@ -559,13 +603,29 @@ public class WeakKeySetTest extends TestCase {
       throw new UnsupportedOperationException();
     }
 
-    public Object singletonCreationLock() {
-      throw new UnsupportedOperationException();
-    }
-
     @Override
     public Map<Class<? extends Annotation>, Scope> getScopes() {
       return ImmutableMap.of();
     }
+
+    @Override
+    public List<ScopeBinding> getScopeBindingsThisLevel() {
+      throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public List<TypeListenerBinding> getTypeListenerBindingsThisLevel() {
+      throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public List<ProvisionListenerBinding> getProvisionListenerBindingsThisLevel() {
+      throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public List<ModuleAnnotatedMethodScannerBinding> getScannerBindingsThisLevel() {
+      throw new UnsupportedOperationException();
+    }
   }
 }
