@@ -19,6 +19,7 @@ package com.google.inject.spi;
 import static com.google.inject.Asserts.assertContains;
 import static com.google.inject.Asserts.getDeclaringSourcePart;
 import static com.google.inject.Asserts.isIncludeStackTraceComplete;
+import static java.util.Comparator.comparing;
 
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Lists;
@@ -485,13 +486,7 @@ public class SpiBindingsTest extends TestCase {
   private final ImmutableSet<Key<?>> BUILT_IN_BINDINGS =
       ImmutableSet.of(Key.get(Injector.class), Key.get(Stage.class), Key.get(Logger.class));
 
-  private final Comparator<Binding<?>> orderByKey =
-      new Comparator<Binding<?>>() {
-        @Override
-        public int compare(Binding<?> a, Binding<?> b) {
-          return a.getKey().toString().compareTo(b.getKey().toString());
-        }
-      };
+  private final Comparator<Binding<?>> orderByKey = comparing(arg -> arg.getKey().toString());
 
   private static class StringProvider implements Provider<String> {
     @Override
