@@ -23,7 +23,7 @@ if [ "$TRAVIS_REPO_SLUG" == "google/guice" ] && \
   cp -rf $HOME/api-diffs-latest api-docs/latest/api-diffs
   cp -rf $HOME/javadoc-latest api-docs/latest/javadoc
   git add -f .
-  git commit -m "Lastest javadoc & api-diffs on successful travis build $TRAVIS_BUILD_NUMBER auto-pushed to gh-pages"
+  git commit -m "Latest javadoc & api-diffs on successful travis build $TRAVIS_BUILD_NUMBER auto-pushed to gh-pages"
   git push -fq origin gh-pages > /dev/null
 
   echo -e "Published Javadoc & JDiff to gh-pages.\n"
